Skip to contents

Coercion methods to convert dbMatrix objects to in-memory matrix objects. Respects dbMatrix.max_mem_convert option to prevent OOM errors.

Value

A base R matrix containing the collected matrix values with the same dimensions and dimnames as the source object.