Skip to contents

See methods::Arith for more details.

See methods::Arith for more details.

See methods::Arith for more details.

See methods::Ops for more details.

See methods::Ops for more details.

See methods::Ops for more details.

Usage

# S4 method for class 'dbMatrix,ANY'
Arith(e1, e2)

# S4 method for class 'ANY,dbMatrix'
Arith(e1, e2)

# S4 method for class 'dbMatrix,dbMatrix'
Arith(e1, e2)

# S4 method for class 'dbMatrix,ANY'
Ops(e1, e2)

# S4 method for class 'ANY,dbMatrix'
Ops(e1, e2)

# S4 method for class 'dbMatrix,dbMatrix'
Ops(e1, e2)

# S4 method for class 'DBIConnection'
dbLoad(conn, name, class)

# S4 method for class 'dbMatrix'
writeMM(obj, file, ...)

Arguments

e1

First operand.

e2

Second operand.

conn

DBIConnection object

name

valid name value (character)

class

character, class of the dbMatrix object (e.g. "dbDenseMatrix" or "dbSparseMatrix")

obj

dbMatrix object

file

path to file

...

additional arguments

Value

  • Arithmetic and logical group methods return a dbMatrix object of the appropriate dense or sparse subclass, with the same dimensions as the input and transformed values stored in DuckDB.

  • dbLoad() returns a dbDenseMatrix or dbSparseMatrix pointing to an existing DuckDB table.

  • writeMM() writes a Matrix Market file to file and returns invisible(TRUE) on success.