Skip to contents

Get or set the length of vectors (including lists) and factors, and of any other R object for which a method has been defined.

Usage

# S4 method for class 'dbMatrix'
length(x)

Arguments

x

dbMatrix object

Value

A length-one integer giving the number of stored elements in x.