See methods::Arith for more details.
See methods::Arith for more details.
See methods::Arith for more details.
See methods::Ops for more details.
See methods::Ops for more details.
See methods::Ops for more details.
Usage
# S4 method for class 'dbMatrix,ANY'
Arith(e1, e2)
# S4 method for class 'ANY,dbMatrix'
Arith(e1, e2)
# S4 method for class 'dbMatrix,dbMatrix'
Arith(e1, e2)
# S4 method for class 'dbMatrix,ANY'
Ops(e1, e2)
# S4 method for class 'ANY,dbMatrix'
Ops(e1, e2)
# S4 method for class 'dbMatrix,dbMatrix'
Ops(e1, e2)
# S4 method for class 'DBIConnection'
dbLoad(conn, name, class)
# S4 method for class 'dbMatrix'
writeMM(obj, file, ...)Value
Arithmetic and logical group methods return a
dbMatrixobject of the appropriate dense or sparse subclass, with the same dimensions as the input and transformed values stored in DuckDB.dbLoad()returns adbDenseMatrixordbSparseMatrixpointing to an existing DuckDB table.writeMM()writes a Matrix Market file tofileand returnsinvisible(TRUE)on success.